pynagsystemd [![Build Status](https://travis-ci.org/kbytesys/pynagsystemd.svg?branch=master)](https://travis-ci.org/kbytesys/pynagsystemd)
============

Simple and easy nagios check for systemd status.

This Python script will report a degraded system to nagios and requires only the nagiosplugin library.

You can also test a single service with -s parameter.

Released under GNU GPLv2 License.
